// import { getToken } from "@/utils/auth";

const request = ({
  url,
  data,
  header,
  method = "GET",
  showLoading = true,
  showErrorToast = true,
} = {}) => {
  return new Promise((resolve, reject) => {
    if (showLoading) uni.showLoading({ title: "加载中" });
    uni.request({
      url: `${import.meta.env.VITE_API_BASE_URL}${url}`,
      method,
      data,
      header: { ...header, token: "", version: "1.0" },
      success: (res) =>
        handleSuccessCallback({
          res,
          resolve,
          reject,
          showLoading,
          showErrorToast,
        }),
      fail: (_) => handleFailCallback({ reject }),
    });
  });
};

// 上传文件
const upload = ({ url, filePath, name }) => {
  return new Promise((resolve, reject) => {
    uni.showLoading({ title: "加载中" });
    uni.uploadFile({
      url: `${import.meta.env.VITE_API_BASE_URL}${url}`,
      header: { token: "" },
      filePath,
      name,
      success: (res) => handleSuccessCallback({ res, resolve, reject }),
      fail: (_) => handleFailCallback({ reject }),
    });
  });
};

const handleSuccessCallback = ({
  res,
  resolve,
  reject,
  showLoading = true,
  showErrorToast = true,
}) => {
  if (showLoading) uni.hideLoading();
  let { statusCode, data } = res;

  const isSuccess = isHTTPSuccess(statusCode);
  if (!isSuccess) {
    if (showErrorToast)
      uni.showToast({ icon: "none", title: "网络错误请重新尝试" });
    reject({ msg: `网络错误${statusCode}`, detail: res });
  }
  if (isJSONString(data)) data = JSON.parse(data);

  if (data.errorCode === "NO-ERROR") {
    // 业务处理成功
    resolve(data);
  } else if (data.errorCode === "xxxxxx") {
    // 登录过期
    // const { gotoLogin, setToken } = useAuth();
    // setToken("");
    // gotoLogin();
    // reject({ msg: data.msg, detail: res });
  } else {
    if (showErrorToast) uni.showToast({ icon: "none", title: data.msg });
    reject({ msg: data.msg, detail: res });
  }
};

const handleFailCallback = ({
  reject,
  showLoading = true,
  showErrorToast = true,
}) => {
  if (showLoading) uni.hideLoading();
  if (showErrorToast) {
    uni.showToast({ icon: "none", title: "网络错误请重新尝试" });
  }
  reject({ msg: "网络错误", detail: null });
};

/**
 * 判断请求状态是否成功
 * 参数：http状态码
 * 返回值：[Boolen]
 */
const isHTTPSuccess = (status) => {
  return (status >= 200 && status < 300) || status === 304;
};

const isJSONString = (str) => {
  if (typeof str === "string") {
    try {
      JSON.parse(str);
      return true;
    } catch (error) {
      return false;
    }
  }
  return false;
};

export { request, upload };
